@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package App::Spec::Schema;
 
-our $VERSION = 'v0.15.0'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 use base 'Exporter';
 our @EXPORT_OK = qw/ $SCHEMA /;
@@ -157,11 +157,7 @@ $SCHEMA = {
         'flag',
         'string',
         'integer',
-        'float',
-        'file',
-        'filename',
-        'dir',
-        'dirname'
+        'file'
       ]
     },
     'options' => {
